@@ -14,7 +14,9 @@ has ua   => sub {
 
   # Fresh user agent
   require Mojo::UserAgent;
-  my $ua = Mojo::UserAgent->new(log => $self->log)->app($self);
+  my $ua = Mojo::UserAgent->new->app($self);
+  weaken $self;
+  $ua->on(error => sub { $self->log->error(pop) });
   weaken $ua->{app};
 
   return $ua;
