@@ -17,10 +17,24 @@ has timeout => 15;
 #  Iran, Iraq, China, Mordor, the hoochies that laid low Tiger Woods,
 #  undesirable immigrants - by which I mean everyone that came after me,
 #  including my children..."
-sub DESTROY { shift->_close }
+sub DESTROY { shift->close }
 
 sub new { shift->SUPER::new(handle => shift, buffer => '', active => time) }
 
+sub close {
+  my $self = shift;
+
+  # Cleanup
+  return unless my $watcher = $self->{iowatcher};
+  $watcher->drop_timer(delete $self->{timer}) if $self->{timer};
+  return unless my $handle = delete $self->{handle};
+  $watcher->drop_handle($handle);
+
+  # Close
+  close $handle;
+  $self->emit_safe('close');
+}
+
 sub handle { shift->{handle} }
 
 sub is_readable {
@@ -48,7 +62,7 @@ sub resume {
   weaken $self;
   $self->{timer} ||= $watcher->recurring(
     '0.025' => sub {
-      $self->emit_safe('timeout')->_close
+      $self->emit_safe('timeout')->close
         if $self && (time - ($self->{active})) >= $self->timeout;
     }
   );
@@ -88,20 +102,6 @@ sub write {
     if $self->{handle};
 }
 
-sub _close {
-  my $self = shift;
-
-  # Cleanup
-  return unless my $handle  = delete $self->{handle};
-  return unless my $watcher = $self->{iowatcher};
-  $watcher->drop_handle($handle);
-  $watcher->drop_timer(delete $self->{timer}) if $self->{timer};
-
-  # Close
-  close $handle;
-  $self->emit_safe('close');
-}
-
 sub _read {
   my $self = shift;
 
@@ -115,14 +115,14 @@ sub _read {
     return if $! ~~ [EAGAIN, EINTR, EWOULDBLOCK];
 
     # Closed
-    return $self->_close if $! == ECONNRESET;
+    return $self->close if $! == ECONNRESET;
 
     # Read error
-    return $self->emit_safe(error => $!)->_close;
+    return $self->emit_safe(error => $!)->close;
   }
 
   # EOF
-  return $self->_close if $read == 0;
+  return $self->close if $read == 0;
 
   # Handle read
   $self->emit_safe(read => $buffer);
@@ -146,10 +146,10 @@ sub _write {
       return if $! ~~ [EAGAIN, EINTR, EWOULDBLOCK];
 
       # Closed
-      return $self->_close if $! ~~ [ECONNRESET, EPIPE];
+      return $self->close if $! ~~ [ECONNRESET, EPIPE];
 
       # Write error
-      return $self->emit_safe(error => $!)->_close;
+      return $self->emit_safe(error => $!)->close;
     }
 
     # Remove written chunk from buffer
@@ -209,6 +209,7 @@ L<Mojo::IOLoop::Stream> can emit the following events.
 
   $stream->on(close => sub {
     my $stream = shift;
+    ...
   });
 
 Emitted safely if the stream gets closed.
@@ -217,6 +218,7 @@ Emitted safely if the stream gets closed.
 
   $stream->on(drain => sub {
     my $stream = shift;
+    ...
   });
 
 Emitted safely once all data has been written.
@@ -225,6 +227,7 @@ Emitted safely once all data has been written.
 
   $stream->on(error => sub {
     my ($stream, $err) = @_;
+    ...
   });
 
 Emitted safely if an error happens on the stream.
@@ -233,6 +236,7 @@ Emitted safely if an error happens on the stream.
 
   $stream->on(read => sub {
     my ($stream, $chunk) = @_;
+    ...
   });
 
 Emitted safely if new data arrives on the stream.
@@ -241,6 +245,7 @@ Emitted safely if new data arrives on the stream.
 
   $stream->on(timeout => sub {
     my $stream = shift;
+    ...
   });
 
 Emitted safely if the stream has been inactive for too long and will get
@@ -251,6 +256,7 @@ without warning!
 
   $stream->on(write => sub {
     my ($stream, $chunk) = @_;
+    ...
   });
 
 Emitted safely if new data has been written to the stream.
@@ -287,6 +293,12 @@ implements the following new ones.
 
 Construct a new L<Mojo::IOLoop::Stream> object.
 
+=head2 C<close>
+
+  $stream->close;
+
+Close stream immediately.
+
 =head2 C<handle>
 
   my $handle = $stream->handle;
