@@ -32,7 +32,7 @@ has static   => sub { Mojolicious::Static->new };
 has types    => sub { Mojolicious::Types->new };
 
 our $CODENAME = 'Leaf Fluttering In Wind';
-our $VERSION  = '2.38';
+our $VERSION  = '2.39';
 
 # "These old doomsday devices are dangerously unstable.
 #  I'll rest easier not knowing where they are."
@@ -110,8 +110,6 @@ sub build_tx {
   return $tx;
 }
 
-# "Amy, technology isn't intrinsically good or evil. It's how it's used.
-#  Like the Death Ray."
 sub defaults {
   my $self = shift;
 
@@ -200,8 +198,6 @@ sub handler {
     unless $stash->{'mojo.rendered'} || $tx->is_writing;
 }
 
-# "This snow is beautiful. I'm glad global warming never happened.
-#  Actually, it did. But thank God nuclear winter canceled it out."
 sub helper {
   my ($self, $name) = (shift, shift);
   my $r = $self->renderer;
@@ -473,7 +469,7 @@ These hooks are currently available and are emitted in the listed order:
 
 =over 2
 
-=item after_build_tx
+=item B<after_build_tx>
 
 Emitted right after the transaction is built and before the HTTP request gets
 parsed.
@@ -487,7 +483,7 @@ rather advanced features such as upload progress bars possible, just note
 that it will not work for embedded applications. (Passed the transaction and
 application instances)
 
-=item before_dispatch
+=item B<before_dispatch>
 
 Emitted right before the static and routes dispatchers start their work.
 
@@ -498,7 +494,7 @@ Emitted right before the static and routes dispatchers start their work.
 Very useful for rewriting incoming requests and other preprocessing tasks.
 (Passed the default controller instance)
 
-=item after_static_dispatch
+=item B<after_static_dispatch>
 
 Emitted in reverse order after the static dispatcher determined if a static
 file should be served and before the routes dispatcher starts its work.
@@ -510,7 +506,7 @@ file should be served and before the routes dispatcher starts its work.
 Mostly used for custom dispatchers and postprocessing static file responses.
 (Passed the default controller instance)
 
-=item after_dispatch
+=item B<after_dispatch>
 
 Emitted in reverse order after a response has been rendered. Note that this
 hook can trigger before C<after_static_dispatch> due to its dynamic nature.
@@ -522,7 +518,7 @@ hook can trigger before C<after_static_dispatch> due to its dynamic nature.
 Useful for all kinds of postprocessing tasks. (Passed the current controller
 instance)
 
-=item around_dispatch
+=item B<around_dispatch>
 
 Emitted right before the C<before_dispatch> hook and wraps around the whole
 dispatch process, so you have to manually forward to the next hook if you
@@ -646,21 +642,21 @@ change controller state, which includes request, response and stash.
 
 =head2 Web
 
-  http://mojolicio.us
+L<http://mojolicio.us>
 
 =head2 IRC
 
-  #mojo on irc.perl.org
+C<#mojo> on C<irc.perl.org>
 
 =head2 Mailing-List
 
-  http://groups.google.com/group/mojolicious
+L<http://groups.google.com/group/mojolicious>
 
 =head1 DEVELOPMENT
 
 =head2 Repository
 
-  http://github.com/kraih/mojo
+L<http://github.com/kraih/mojo>
 
 =head1 BUNDLED FILES
 
@@ -912,6 +908,8 @@ Victor Engmark
 
 Viliam Pucik
 
+Wes Cravens
+
 Yaroslav Korshak
 
 Yuki Kimoto
